@@ -5,8 +5,20 @@ use serde::Deserialize;
 use std::collections::HashMap;
 use std::path::PathBuf;
 
+#[derive(Debug)]
+struct ManifestParseError(String);
+
+impl std::fmt::Display for ManifestParseError {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "There is an error: {}", self.0)
+    }
+}
+impl std::error::Error for ManifestParseError {}
+
 #[derive(Debug, Deserialize)]
 pub struct Manifest {
+    #[serde(default = "default_difftool")]
+    pub(crate) difftool: String,
     pub(crate) since: String,
     #[serde(skip)]
     pub(crate) since_datetime: Option<chrono::DateTime<chrono::Utc>>,
@@ -17,6 +29,7 @@ pub struct Manifest {
 impl Default for Manifest {
     fn default() -> Self {
         Self {
+            difftool: "git difftool -g -y".to_string(),
             since: "1 week ago".to_string(),
             since_datetime: None,
             remotes: HashMap::new(),
@@ -32,6 +45,11 @@ impl Manifest {
 
         let mut manifest: Manifest = toml::from_str(&manifest_contents)?;
         let since_datetime = time::parse_relative(&manifest.since, &chrono::Utc::now())?;
+        if manifest.difftool.len() <= 0 {
+            return Err(Box::new(ManifestParseError(format!(
+                "When difftool is present in manifest, it must have length > 0"
+            ))));
+        }
         manifest.root = Some(root);
         manifest.since_datetime = Some(since_datetime);
         Ok(manifest)
@@ -43,3 +61,7 @@ pub struct Remote {
     pub(crate) name: String,
     pub(crate) origin: String,
 }
+
+fn default_difftool() -> String {
+    "git difftool -g -y".to_string()
+}
